@@ -18,14 +18,19 @@ def subtract(obj1, obj2):
                 return res
         elif isinstance(obj1, list) or isinstance(obj1, tuple):
             res = list()
-            for v in obj1:
-                found = False
-                for i in range(len(obj2)):
-                    if equal(v, obj2[i]):
-                        found = True
-                        break
-                if not found:
-                    res.append(v)
+            if len(obj1) == 1 and len(obj2) == 1:
+                ele = subtract(obj1[0], obj2[0])
+                if ele and len(ele):
+                    res.append(ele)
+            else:
+                for v in obj1:
+                    found = False
+                    for i in range(len(obj2)):
+                        if equal(v, obj2[i]):
+                            found = True
+                            break
+                    if not found:
+                        res.append(v)
             if len(res) > 0:
                 return res
         else:
